=== modified file 'drizzled/session/cache.cc'
--- drizzled/session/cache.cc	2011-04-20 09:12:02 +0000
+++ drizzled/session/cache.cc	2011-06-17 07:07:02 +0000
@@ -19,12 +19,12 @@
 
 #include <config.h>
 #include <drizzled/session/cache.h>
-
-#include <boost/foreach.hpp>
-#include <drizzled/current_session.h>
-#include <drizzled/plugin/authorization.h>
-#include <drizzled/session.h>
-#include <vector>
+
+#include <boost/foreach.hpp>
+#include <drizzled/current_session.h>
+#include <drizzled/plugin/authorization.h>
+#include <drizzled/session.h>
+#include <vector>
 
 namespace drizzled {
 namespace session {

=== modified file 'libdrizzle-2.0/libdrizzle/libdrizzle.hpp'
--- libdrizzle-2.0/libdrizzle/libdrizzle.hpp	2011-06-17 07:05:46 +0000
+++ libdrizzle-2.0/libdrizzle/libdrizzle.hpp	2011-06-17 09:09:26 +0000
@@ -31,47 +31,47 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#pragma once
-
-#include <cstring>
-#include <libdrizzle/libdrizzle.h>
-#include <stdexcept>
-
-namespace drizzle {
-
-class bad_query : public std::runtime_error
-{
-};
-
-class drizzle_c
-{
-public:
-  drizzle_c()
-  {
-    drizzle_create(&b_);
-  }
-
-  ~drizzle_c()
-  {
-    drizzle_free(&b_);
-  }
-
-  drizzle_st b_;
-};
-
-class result_c
-{
-public:
-  result_c()
-  {
-    memset(&b_, 0, sizeof(b_));
-  }
-
-  ~result_c()
-  {
-    drizzle_result_free(&b_);
-  }
-
+#pragma once
+
+#include <cstring>
+#include <libdrizzle/libdrizzle.h>
+#include <stdexcept>
+
+namespace drizzle {
+
+class bad_query : public std::runtime_error
+{
+};
+
+class drizzle_c
+{
+public:
+  drizzle_c()
+  {
+    drizzle_create(&b_);
+  }
+
+  ~drizzle_c()
+  {
+    drizzle_free(&b_);
+  }
+
+  drizzle_st b_;
+};
+
+class result_c
+{
+public:
+  result_c()
+  {
+    memset(&b_, 0, sizeof(b_));
+  }
+
+  ~result_c()
+  {
+    drizzle_result_free(&b_);
+  }
+
   const char* error()
   {
     return drizzle_result_error(&b_);
@@ -116,28 +116,28 @@
   {
     return drizzle_row_field_sizes(&b_);
   }
-
-  drizzle_result_st b_;
-};
-
-class connection_c
-{
-public:
-  explicit connection_c(drizzle_c& drizzle)
-  {
-    drizzle_con_create(&drizzle.b_, &b_);
-  }
-
-  ~connection_c()
-  {
-    drizzle_con_free(&b_);
-  }
-
-  const char* error()
-  {
-    return drizzle_con_error(&b_);
-  }
-
+
+  drizzle_result_st b_;
+};
+
+class connection_c
+{
+public:
+  explicit connection_c(drizzle_c& drizzle)
+  {
+    drizzle_con_create(&drizzle.b_, &b_);
+  }
+
+  ~connection_c()
+  {
+    drizzle_con_free(&b_);
+  }
+
+  const char* error()
+  {
+    return drizzle_con_error(&b_);
+  }
+
   drizzle_return_t query(result_c& result, const char* str, size_t str_size)
   {
     drizzle_return_t ret;
@@ -145,21 +145,21 @@
     if (ret == DRIZZLE_RETURN_OK)
       ret = drizzle_result_buffer(&result.b_);
     return ret;
-  }
-
-  drizzle_return_t query(result_c& result, const std::string& str)
-  {
-    return query(result, str.data(), str.size());
-  }
-
-  drizzle_return_t query(result_c& result, const char* str)
-  {
-    return query(result, str, strlen(str));
-  }
-
-  drizzle_con_st b_;
-};
-
+  }
+
+  drizzle_return_t query(result_c& result, const std::string& str)
+  {
+    return query(result, str.data(), str.size());
+  }
+
+  drizzle_return_t query(result_c& result, const char* str)
+  {
+    return query(result, str, strlen(str));
+  }
+
+  drizzle_con_st b_;
+};
+
 /*
 inline drizzle_return_t query(drizzle_con_st* con, result_c& result, const char* str, size_t str_size)
 {
@@ -168,17 +168,17 @@
   if (ret == DRIZZLE_RETURN_OK)
     ret = drizzle_result_buffer(&result.b_);
   return ret;
-}
-
+}
+
 inline drizzle_return_t query(drizzle_con_st* con, result_c& result, const std::string& str)
 {
   return query(con, result, str.data(), str.size());
-}
-
+}
+
 inline drizzle_return_t query(drizzle_con_st* con, result_c& result, const char* str)
 {
   return query(con, result, str, strlen(str));
-}
-*/
-
-}
+}
+*/
+
+}

=== modified file 'win32/drizzle.sln'
--- win32/drizzle.sln	2011-04-03 18:32:46 +0000
+++ win32/drizzle.sln	2011-06-17 07:07:02 +0000
@@ -1,26 +1,26 @@
-﻿
-Microsoft Visual Studio Solution File, Format Version 11.00
-# Visual Studio 2010
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "libdrizzle-2.0", "libdrizzle-2.0.vcxproj", "{786CDCC5-9B40-4927-B8B3-DC484E138EE9}"
-EndProject
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "libdrizzle-1.0", "libdrizzle-1.0.vcxproj", "{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}"
-EndProject
-Global
-	GlobalSection(SolutionConfigurationPlatforms) = preSolution
-		Debug|Win32 = Debug|Win32
-		Release|Win32 = Release|Win32
-	EndGlobalSection
-	GlobalSection(ProjectConfigurationPlatforms) = postSolution
-		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Debug|Win32.ActiveCfg = Debug|Win32
-		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Debug|Win32.Build.0 = Debug|Win32
-		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Release|Win32.ActiveCfg = Release|Win32
-		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Release|Win32.Build.0 = Release|Win32
-		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Debug|Win32.ActiveCfg = Debug|Win32
-		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Debug|Win32.Build.0 = Debug|Win32
-		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Release|Win32.ActiveCfg = Release|Win32
-		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Release|Win32.Build.0 = Release|Win32
-	EndGlobalSection
-	GlobalSection(SolutionProperties) = preSolution
-		HideSolutionNode = FALSE
-	EndGlobalSection
-EndGlobal
+﻿
+Microsoft Visual Studio Solution File, Format Version 11.00
+# Visual Studio 2010
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "libdrizzle-2.0", "libdrizzle-2.0.vcxproj", "{786CDCC5-9B40-4927-B8B3-DC484E138EE9}"
+EndProject
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "libdrizzle-1.0", "libdrizzle-1.0.vcxproj", "{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}"
+EndProject
+Global
+	GlobalSection(SolutionConfigurationPlatforms) = preSolution
+		Debug|Win32 = Debug|Win32
+		Release|Win32 = Release|Win32
+	EndGlobalSection
+	GlobalSection(ProjectConfigurationPlatforms) = postSolution
+		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Debug|Win32.ActiveCfg = Debug|Win32
+		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Debug|Win32.Build.0 = Debug|Win32
+		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Release|Win32.ActiveCfg = Release|Win32
+		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Release|Win32.Build.0 = Release|Win32
+		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Debug|Win32.ActiveCfg = Debug|Win32
+		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Debug|Win32.Build.0 = Debug|Win32
+		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Release|Win32.ActiveCfg = Release|Win32
+		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Release|Win32.Build.0 = Release|Win32
+	EndGlobalSection
+	GlobalSection(SolutionProperties) = preSolution
+		HideSolutionNode = FALSE
+	EndGlobalSection
+EndGlobal

=== modified file 'win32/libdrizzle-1.0.vcxproj'
--- win32/libdrizzle-1.0.vcxproj	2011-04-03 18:32:46 +0000
+++ win32/libdrizzle-1.0.vcxproj	2011-06-17 07:07:02 +0000
@@ -1,144 +1,144 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup Label="ProjectConfigurations">
-    <ProjectConfiguration Include="Debug|Win32">
-      <Configuration>Debug</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release|Win32">
-      <Configuration>Release</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-  </ItemGroup>
-  <PropertyGroup Label="Globals">
-    <ProjectGuid>{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}</ProjectGuid>
-    <RootNamespace>libdrizzle10</RootNamespace>
-    <Keyword>Win32Proj</Keyword>
-    <ProjectName>libdrizzle-1.0</ProjectName>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
-  <ImportGroup Label="ExtensionSettings">
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-  </ImportGroup>
-  <PropertyGroup Label="UserMacros" />
-  <PropertyGroup>
-    <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">true</LinkIncremental>
-    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
-    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
-    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
-    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
-    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
-    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
-  </PropertyGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-    <ClCompile>
-      <Optimization>Disabled</Optimization>
-      <AdditionalIncludeDirectories>$(ProjectDir)\windows;$(ProjectDir);$(ProjectDir)\..\libdrizzle-1.0;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;_DEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MinimalRebuild>true</MinimalRebuild>
-      <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
-      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
-      <PrecompiledHeader>
-      </PrecompiledHeader>
-      <WarningLevel>Level3</WarningLevel>
-      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
-      <CompileAs>CompileAsC</CompileAs>
-    </ClCompile>
-    <Link>
-      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <SubSystem>Windows</SubSystem>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-    <ClCompile>
-      <AdditionalIncludeDirectories>$(ProjectDir)\..\libdrizzle-1.0;$(ProjectDir)\windows;$(ProjectDir);%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;NDEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
-      <PrecompiledHeader>
-      </PrecompiledHeader>
-      <WarningLevel>Level3</WarningLevel>
-      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
-    </ClCompile>
-    <Link>
-      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <SubSystem>Windows</SubSystem>
-      <OptimizeReferences>true</OptimizeReferences>
-      <EnableCOMDATFolding>true</EnableCOMDATFolding>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemGroup>
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\command_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\command_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\common.h" />
-    <ClInclude Include="config.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_local.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\constants.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_local.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\field_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\field_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\handshake_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\handshake_server.h" />
-    <ClInclude Include="windows\inttypes.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\pack.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\query.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\row_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\row_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\sha1.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\state.h" />
-    <ClInclude Include="windows\stdint.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\structs.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\visibility.h" />
-  </ItemGroup>
-  <ItemGroup>
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\column.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\command.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\conn.c" />
-    <ClCompile Include="conn_uds.cc" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\drizzle.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\field.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\handshake.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\pack.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\query.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\result.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\row.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\sha1.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\state.c" />
-  </ItemGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
-  <ImportGroup Label="ExtensionTargets">
-  </ImportGroup>
-</Project>
+﻿<?xml version="1.0" encoding="utf-8"?>
+<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup Label="ProjectConfigurations">
+    <ProjectConfiguration Include="Debug|Win32">
+      <Configuration>Debug</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release|Win32">
+      <Configuration>Release</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+  </ItemGroup>
+  <PropertyGroup Label="Globals">
+    <ProjectGuid>{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}</ProjectGuid>
+    <RootNamespace>libdrizzle10</RootNamespace>
+    <Keyword>Win32Proj</Keyword>
+    <ProjectName>libdrizzle-1.0</ProjectName>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
+    <ConfigurationType>DynamicLibrary</ConfigurationType>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
+    <ConfigurationType>DynamicLibrary</ConfigurationType>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
+  <ImportGroup Label="ExtensionSettings">
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <PropertyGroup Label="UserMacros" />
+  <PropertyGroup>
+    <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">true</LinkIncremental>
+    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
+    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
+    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
+    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
+    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
+    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
+  </PropertyGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <ClCompile>
+      <Optimization>Disabled</Optimization>
+      <AdditionalIncludeDirectories>$(ProjectDir)\windows;$(ProjectDir);$(ProjectDir)\..\libdrizzle-1.0;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>WIN32;_DEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MinimalRebuild>true</MinimalRebuild>
+      <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
+      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
+      <PrecompiledHeader>
+      </PrecompiledHeader>
+      <WarningLevel>Level3</WarningLevel>
+      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
+      <CompileAs>CompileAsC</CompileAs>
+    </ClCompile>
+    <Link>
+      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <SubSystem>Windows</SubSystem>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <ClCompile>
+      <AdditionalIncludeDirectories>$(ProjectDir)\..\libdrizzle-1.0;$(ProjectDir)\windows;$(ProjectDir);%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>WIN32;NDEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
+      <PrecompiledHeader>
+      </PrecompiledHeader>
+      <WarningLevel>Level3</WarningLevel>
+      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
+    </ClCompile>
+    <Link>
+      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <SubSystem>Windows</SubSystem>
+      <OptimizeReferences>true</OptimizeReferences>
+      <EnableCOMDATFolding>true</EnableCOMDATFolding>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemGroup>
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\command_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\command_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\common.h" />
+    <ClInclude Include="config.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_local.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\constants.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_local.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\field_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\field_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\handshake_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\handshake_server.h" />
+    <ClInclude Include="windows\inttypes.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\pack.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\query.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\row_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\row_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\sha1.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\state.h" />
+    <ClInclude Include="windows\stdint.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\structs.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\visibility.h" />
+  </ItemGroup>
+  <ItemGroup>
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\column.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\command.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\conn.c" />
+    <ClCompile Include="conn_uds.cc" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\drizzle.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\field.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\handshake.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\pack.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\query.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\result.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\row.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\sha1.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\state.c" />
+  </ItemGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
+  <ImportGroup Label="ExtensionTargets">
+  </ImportGroup>
+</Project>

=== modified file 'win32/libdrizzle-1.0.vcxproj.filters'
--- win32/libdrizzle-1.0.vcxproj.filters	2011-04-03 18:32:46 +0000
+++ win32/libdrizzle-1.0.vcxproj.filters	2011-06-17 07:07:02 +0000
@@ -1,17 +1,17 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup>
-    <Filter Include="Source Files">
-      <UniqueIdentifier>{4FC737F1-C7A5-4376-A066-2A32D752A2FF}</UniqueIdentifier>
-      <Extensions>cpp;c;cc;cxx;def;odl;idl;hpj;bat;asm;asmx</Extensions>
-    </Filter>
-    <Filter Include="Header Files">
-      <UniqueIdentifier>{93995380-89BD-4b04-88EB-625FBE52EBFB}</UniqueIdentifier>
-      <Extensions>h;hpp;hxx;hm;inl;inc;xsd</Extensions>
-    </Filter>
-    <Filter Include="Resource Files">
-      <UniqueIdentifier>{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}</UniqueIdentifier>
-      <Extensions>rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx;tiff;tif;png;wav;mfcribbon-ms</Extensions>
-    </Filter>
-  </ItemGroup>
+﻿<?xml version="1.0" encoding="utf-8"?>
+<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup>
+    <Filter Include="Source Files">
+      <UniqueIdentifier>{4FC737F1-C7A5-4376-A066-2A32D752A2FF}</UniqueIdentifier>
+      <Extensions>cpp;c;cc;cxx;def;odl;idl;hpj;bat;asm;asmx</Extensions>
+    </Filter>
+    <Filter Include="Header Files">
+      <UniqueIdentifier>{93995380-89BD-4b04-88EB-625FBE52EBFB}</UniqueIdentifier>
+      <Extensions>h;hpp;hxx;hm;inl;inc;xsd</Extensions>
+    </Filter>
+    <Filter Include="Resource Files">
+      <UniqueIdentifier>{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}</UniqueIdentifier>
+      <Extensions>rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx;tiff;tif;png;wav;mfcribbon-ms</Extensions>
+    </Filter>
+  </ItemGroup>
 </Project>
\ No newline at end of file

=== modified file 'win32/libdrizzle-2.0.vcxproj'
--- win32/libdrizzle-2.0.vcxproj	2011-04-03 19:25:54 +0000
+++ win32/libdrizzle-2.0.vcxproj	2011-06-17 07:07:02 +0000
@@ -1,143 +1,143 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup Label="ProjectConfigurations">
-    <ProjectConfiguration Include="Debug|Win32">
-      <Configuration>Debug</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release|Win32">
-      <Configuration>Release</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-  </ItemGroup>
-  <PropertyGroup Label="Globals">
-    <ProjectGuid>{786CDCC5-9B40-4927-B8B3-DC484E138EE9}</ProjectGuid>
-    <RootNamespace>libdrizzle</RootNamespace>
-    <Keyword>Win32Proj</Keyword>
-    <ProjectName>libdrizzle-2.0</ProjectName>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
-  <ImportGroup Label="ExtensionSettings">
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-  </ImportGroup>
-  <PropertyGroup Label="UserMacros" />
-  <PropertyGroup>
-    <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">true</LinkIncremental>
-    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
-    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
-    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
-    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
-    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
-    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
-  </PropertyGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-    <ClCompile>
-      <Optimization>Disabled</Optimization>
-      <AdditionalIncludeDirectories>$(ProjectDir)\windows;$(ProjectDir);$(ProjectDir)\..\libdrizzle-2.0;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;_DEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MinimalRebuild>true</MinimalRebuild>
-      <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
-      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
-      <PrecompiledHeader>
-      </PrecompiledHeader>
-      <WarningLevel>Level3</WarningLevel>
-      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
-    </ClCompile>
-    <Link>
-      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <SubSystem>Windows</SubSystem>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-    <ClCompile>
-      <AdditionalIncludeDirectories>$(ProjectDir)\..\libdrizzle-2.0;$(ProjectDir)\windows;$(ProjectDir);%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;NDEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
-      <PrecompiledHeader>
-      </PrecompiledHeader>
-      <WarningLevel>Level3</WarningLevel>
-      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
-    </ClCompile>
-    <Link>
-      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <SubSystem>Windows</SubSystem>
-      <OptimizeReferences>true</OptimizeReferences>
-      <EnableCOMDATFolding>true</EnableCOMDATFolding>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemGroup>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\common.h" />
-    <ClInclude Include="config.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_local.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\constants.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_local.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_server.h" />
-    <ClInclude Include="windows\inttypes.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\pack.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\query.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\sha1.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\state.h" />
-    <ClInclude Include="windows\stdint.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\structs.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\visibility.h" />
-  </ItemGroup>
-  <ItemGroup>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\column.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\command.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\conn.cc" />
-    <ClCompile Include="conn_uds.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\drizzle.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\field.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\handshake.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\pack.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\query.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\result.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\row.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\sha1.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\state.cc" />
-  </ItemGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
-  <ImportGroup Label="ExtensionTargets">
-  </ImportGroup>
+﻿<?xml version="1.0" encoding="utf-8"?>
+<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup Label="ProjectConfigurations">
+    <ProjectConfiguration Include="Debug|Win32">
+      <Configuration>Debug</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release|Win32">
+      <Configuration>Release</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+  </ItemGroup>
+  <PropertyGroup Label="Globals">
+    <ProjectGuid>{786CDCC5-9B40-4927-B8B3-DC484E138EE9}</ProjectGuid>
+    <RootNamespace>libdrizzle</RootNamespace>
+    <Keyword>Win32Proj</Keyword>
+    <ProjectName>libdrizzle-2.0</ProjectName>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
+    <ConfigurationType>DynamicLibrary</ConfigurationType>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
+    <ConfigurationType>DynamicLibrary</ConfigurationType>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
+  <ImportGroup Label="ExtensionSettings">
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <PropertyGroup Label="UserMacros" />
+  <PropertyGroup>
+    <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">true</LinkIncremental>
+    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
+    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
+    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
+    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
+    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
+    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
+  </PropertyGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <ClCompile>
+      <Optimization>Disabled</Optimization>
+      <AdditionalIncludeDirectories>$(ProjectDir)\windows;$(ProjectDir);$(ProjectDir)\..\libdrizzle-2.0;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>WIN32;_DEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MinimalRebuild>true</MinimalRebuild>
+      <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
+      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
+      <PrecompiledHeader>
+      </PrecompiledHeader>
+      <WarningLevel>Level3</WarningLevel>
+      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
+    </ClCompile>
+    <Link>
+      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <SubSystem>Windows</SubSystem>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <ClCompile>
+      <AdditionalIncludeDirectories>$(ProjectDir)\..\libdrizzle-2.0;$(ProjectDir)\windows;$(ProjectDir);%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>WIN32;NDEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
+      <PrecompiledHeader>
+      </PrecompiledHeader>
+      <WarningLevel>Level3</WarningLevel>
+      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
+    </ClCompile>
+    <Link>
+      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <SubSystem>Windows</SubSystem>
+      <OptimizeReferences>true</OptimizeReferences>
+      <EnableCOMDATFolding>true</EnableCOMDATFolding>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemGroup>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\common.h" />
+    <ClInclude Include="config.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_local.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\constants.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_local.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_server.h" />
+    <ClInclude Include="windows\inttypes.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\pack.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\query.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\sha1.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\state.h" />
+    <ClInclude Include="windows\stdint.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\structs.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\visibility.h" />
+  </ItemGroup>
+  <ItemGroup>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\column.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\command.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\conn.cc" />
+    <ClCompile Include="conn_uds.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\drizzle.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\field.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\handshake.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\pack.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\query.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\result.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\row.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\sha1.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\state.cc" />
+  </ItemGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
+  <ImportGroup Label="ExtensionTargets">
+  </ImportGroup>
 </Project>
\ No newline at end of file

=== modified file 'win32/libdrizzle-2.0.vcxproj.filters'
--- win32/libdrizzle-2.0.vcxproj.filters	2011-04-03 18:14:47 +0000
+++ win32/libdrizzle-2.0.vcxproj.filters	2011-06-17 07:07:02 +0000
@@ -1,159 +1,159 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup>
-    <Filter Include="Header Files">
-      <UniqueIdentifier>{93995380-89BD-4b04-88EB-625FBE52EBFB}</UniqueIdentifier>
-      <Extensions>h;hpp;hxx;hm;inl;inc;xsd</Extensions>
-    </Filter>
-    <Filter Include="Resource Files">
-      <UniqueIdentifier>{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}</UniqueIdentifier>
-      <Extensions>rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx</Extensions>
-    </Filter>
-    <Filter Include="Source Files">
-      <UniqueIdentifier>{4FC737F1-C7A5-4376-A066-2A32D752A2FF}</UniqueIdentifier>
-      <Extensions>cpp;c;cc;cxx;def;odl;idl;hpj;bat;asm;asmx</Extensions>
-    </Filter>
-  </ItemGroup>
-  <ItemGroup>
-    <ClInclude Include="config.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="windows\inttypes.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="windows\stdint.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\common.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_local.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\constants.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_local.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\pack.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\query.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\sha1.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\state.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\structs.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\visibility.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-  </ItemGroup>
-  <ItemGroup>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\column.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\command.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\conn.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="conn_uds.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\drizzle.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\field.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\handshake.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\pack.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\query.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\result.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\row.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\sha1.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\state.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-  </ItemGroup>
+﻿<?xml version="1.0" encoding="utf-8"?>
+<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup>
+    <Filter Include="Header Files">
+      <UniqueIdentifier>{93995380-89BD-4b04-88EB-625FBE52EBFB}</UniqueIdentifier>
+      <Extensions>h;hpp;hxx;hm;inl;inc;xsd</Extensions>
+    </Filter>
+    <Filter Include="Resource Files">
+      <UniqueIdentifier>{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}</UniqueIdentifier>
+      <Extensions>rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx</Extensions>
+    </Filter>
+    <Filter Include="Source Files">
+      <UniqueIdentifier>{4FC737F1-C7A5-4376-A066-2A32D752A2FF}</UniqueIdentifier>
+      <Extensions>cpp;c;cc;cxx;def;odl;idl;hpj;bat;asm;asmx</Extensions>
+    </Filter>
+  </ItemGroup>
+  <ItemGroup>
+    <ClInclude Include="config.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="windows\inttypes.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="windows\stdint.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\common.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_local.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\constants.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_local.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\pack.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\query.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\sha1.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\state.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\structs.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\visibility.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+  </ItemGroup>
+  <ItemGroup>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\column.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\command.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\conn.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="conn_uds.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\drizzle.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\field.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\handshake.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\pack.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\query.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\result.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\row.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\sha1.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\state.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+  </ItemGroup>
 </Project>
\ No newline at end of file

